/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.codehaus.plexus.swizzle.jira.authentication;

import javax.inject.Inject;
import javax.inject.Named;

import org.sonatype.inject.Nullable;

@Named( "pr.default" )
public class DefaultAuthenticationSource
    implements AuthenticationSource
{

    private final String login;

    private final String password;

    @Inject
    public DefaultAuthenticationSource( @Nullable @Named( "${pr.auth.login}" ) final String login,
                                        @Nullable @Named( "${pr.auth.password}" ) final String password )
    {
        this.login = login;
        this.password = password;
    }

    @Override
    public String getLogin()
    {
        return login;
    }

    @Override
    public String getPassword()
    {
        return password;
    }

    @Override
    public String toString()
    {
        return "AuthenticationSource: " + login;
    }

    @Override
    public boolean equals( Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( !( o instanceof DefaultAuthenticationSource ) )
        {
            return false;
        }

        DefaultAuthenticationSource that = (DefaultAuthenticationSource) o;

        if ( login != null ? !login.equals( that.login ) : that.login != null )
        {
            return false;
        }
        if ( password != null ? !password.equals( that.password ) : that.password != null )
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = login != null ? login.hashCode() : 0;
        result = 31 * result + ( password != null ? password.hashCode() : 0 );
        return result;
    }
}
