/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.issue;

import java.util.List;

import org.codehaus.plexus.swizzle.jira.authentication.AuthenticationSource;
import org.codehaus.swizzle.jira.Component;
import org.codehaus.swizzle.jira.Filter;
import org.codehaus.swizzle.jira.Issue;
import org.codehaus.swizzle.jira.IssueType;
import org.codehaus.swizzle.jira.Priority;
import org.codehaus.swizzle.jira.Project;
import org.codehaus.swizzle.jira.Version;

/**
 * Retrieve issue information from a remote server.
 *
 * @since 1.4
 */
public interface IssueRetriever
    extends Configurable
{

    Project getProject( String projectKey )
        throws IssueRetrievalException;

    List<Version> getVersions( Project project );

    List<IssueType> getIssueTypes( Project project );

    List<Component> getComponents( Project project );

    List<Priority> getPriorities();

    Priority getPriority( int intValue );

    List<Filter> getFilters()
        throws Exception;

    List<Issue> getIssuesFromFilter( int id )
        throws Exception;

    List<Issue> getIssues( Filter filter )
        throws Exception;

    List<Issue> getIssues( String search )
        throws IssueRetrievalException;

    List<Issue> getIssues( String search, Project project )
        throws IssueRetrievalException;

    List<Issue> getIssues( String search, Project project, int limit )
        throws IssueRetrievalException;

    Component getComponent( Project project, String component )
        throws IssueRetrievalException;

    void setServerUrl( String serverUrl );

    void setCredentials( AuthenticationSource credentials );
}
