/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr;

import org.codehaus.plexus.swizzle.IssueSubmissionException;
import org.codehaus.plexus.swizzle.IssueSubmissionRequest;

/**
 * Get the appropriate project and component for given issue.
 *
 * @since 1.4
 */
public interface ProjectManager
{
    /**
     * Return the appropriate project for the given incident.
     *
     * @return the appropriate project for the given incident. Depending on the implementation, this may be null.
     */
    String getProject( IssueSubmissionRequest request );

    /**
     * Return the appropriate component for the given incident.
     *
     * @return the appropriate component for the given incident. Depending on the implementation, this may be null.
     */
    int getComponentId( IssueSubmissionRequest request )
        throws IssueSubmissionException;

    /**
     * Return the given issue submission request with data filled in by the project manager.
     * 
     * @param request the request to fill, must not be null.
     * @return an autofilled request, based on the given request.
     * @throws IssueSubmissionException
     */
    IssueSubmissionRequest fill( IssueSubmissionRequest request )
        throws IssueSubmissionException;

}