/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle;

import java.io.IOException;
import java.util.Collection;

/**
 * Creates one bundle with the archived/compressed contents of one or more given bundles.
 */
public interface Archiver
{

    /**
     * Create an archived bundle from the given bundle.
     * 
     * @param bundle the bundle to operate on.
     * @return an archived bundle whose contents contain the contents of the given bundle.
     * @throws IOException if an error occurs while creating the archived bundle.
     */
    Bundle createArchive( Bundle bundle )
        throws IOException;

    /**
     * Create an archived bundle from the given bundles.
     * 
     * @param bundles the bundles to operate on.
     * @return an archived bundle whose contents contain the contents of the given bundles.
     * @throws IOException if an error occurs while creating the archived bundle.
     */
    Bundle createArchive( Collection<Bundle> bundles )
        throws IOException;

    /**
     * Return the content type of the resulting archive bundle (e.g. 'application/zip').
     *
     * @return the content type of the resulting archive bundle.
     */
    String getContentType();
}
