/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle;

import java.io.IOException;
import java.io.InputStream;
import java.util.List;

/**
 * Bundles represent attachments to an issue.
 * 
 * @since 1.4
 */
public interface Bundle
{

    /**
     * The name of the bundle.
     */
    String getName();

    /**
     * The content type of the bundle.
     */
    String getContentType();

    /**
     * Returns the stream to read the contents from.
     */
    InputStream getInputStream()
        throws IOException;

    /**
     * The subordinate bundles.
     */
    List<Bundle> getSubBundles();

    /**
     * The length of the content in bytes.
     */
    long getContentLength();

}
