/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle;

import org.codehaus.plexus.swizzle.IssueSubmissionException;
import org.codehaus.plexus.swizzle.IssueSubmissionRequest;

/**
 * Contributor to the automatically assembled bundles that are attached to a submitted issue.
 *
 * @since 1.4
 */
public interface BundleAssembler
{

    /**
     * Determine if the instance will contribute to the attached bundles.
     *
     * @param request the issue submission request to attach bundles to. Never null.
     * @return <code>true</code>, if this assembler will contribute, <code>false</code> otherwise.
     */
    boolean isParticipating( IssueSubmissionRequest request );

    /**
     * Assemble a bundle based on the given request.
     *
     * @param request the issue submission request to attach bundles to. Never null.
     * @return the bundle to attach.
     * @throws IssueSubmissionException if an error happens while assembling the bundle.
     */
    Bundle assemble( IssueSubmissionRequest request )
        throws IssueSubmissionException;

}
