/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle;

import java.io.IOException;
import java.util.List;

import org.codehaus.plexus.swizzle.IssueSubmissionException;
import org.codehaus.plexus.swizzle.IssueSubmissionRequest;

/**
 * @see BundleAssembler
 * @since 1.4
 */
public interface BundleManager
{

    /**
     * Create an archive containing the bundles added for the issue, using the default Archiver.
     *
     * @return a file created from the assembled bundles, never <code>null</code>.
     * @throws IOException
     * @throws IssueSubmissionException
     */
    Bundle createBundle( IssueSubmissionRequest request )
        throws IOException, IssueSubmissionException;

    /**
     * Goes through the default list of {@link BundleAssembler}s that may want to participate for the given issue.
     *
     * @throws IssueSubmissionException if the bundle could not be assembled.
     */
    List<Bundle> assemble( IssueSubmissionRequest request )
        throws IssueSubmissionException;

    /**
     * Goes through the default list of {@link BundleAssembler}s that may want to participate for the given issue.
     *
     * @throws IssueSubmissionException if the bundle could not be assembled
     */
    List<Bundle> assemble( IssueSubmissionRequest request, BundleAssembler... assemblers )
        throws IssueSubmissionException;

    /**
     * Add a single bundle.
     *
     * @param request the reqest to
     * @param bundle the bundle to add, must not be <code>null</code>.
     * @return the file pointing to the bundle storage
     */
    void addBundle( IssueSubmissionRequest request, Bundle bundle );
}
