/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle;

import java.io.IOException;
import java.io.InputStream;
import java.util.LinkedList;
import java.util.List;


public class DirBundle
    implements Bundle
{

    private final String name;

    private final List<Bundle> bundles = new LinkedList<Bundle>();

    public DirBundle( final String name )
    {
        this.name = name;
    }

    @Override
    public List<Bundle> getSubBundles()
    {
        return bundles;
    }

    @Override
    public long getContentLength()
    {
        return -1;
    }

    @Override
    public String getName()
    {
        return name;
    }

    @Override
    public String getContentType()
    {
        return "dir";
    }

    @Override
    public InputStream getInputStream()
        throws IOException
    {
        return null;
    }

    public void addSubBundle( final Bundle bundle )
    {
        bundles.add( bundle );
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( name == null ) ? 0 : name.hashCode() );
        return result;
    }

    @Override
    public boolean equals( final Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( getClass() != obj.getClass() )
        {
            return false;
        }
        DirBundle other = (DirBundle) obj;

        if ( name == null )
        {
            if ( other.name != null )
            {
                return false;
            }
        }
        else if ( !name.equals( other.name ) )
        {
            return false;
        }
        return true;
    }

}
