/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle.internal;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;

import org.sonatype.sisu.pr.bundle.AbstractBundle;
import org.sonatype.sisu.pr.bundle.Bundle;

public class ByteArrayBundle
    extends AbstractBundle
    implements Bundle
{

    private final byte[] array;

    public ByteArrayBundle( final byte[] array, final String name, final String type )
    {
        super( name, type );
        this.array = array;
    }

    @Override
    public long getContentLength()
    {
        return array.length;
    }

    @Override
    protected InputStream openStream()
        throws IOException
    {
        return new ByteArrayInputStream( array );
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = super.hashCode();
        result = prime * result + Arrays.hashCode( array );
        return result;
    }

    @Override
    public boolean equals( final Object obj )
    {
        if ( !super.equals( obj ) )
        {
            return false;
        }

        if ( this == obj )
        {
            return true;
        }
        if ( !super.equals( obj ) )
        {
            return false;
        }
        if ( getClass() != obj.getClass() )
        {
            return false;
        }
        ByteArrayBundle other = (ByteArrayBundle) obj;
        if ( !Arrays.equals( array, other.array ) )
        {
            return false;
        }
        return true;
    }

}
