/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle.internal;

import java.io.File;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Singleton;

import org.codehaus.plexus.swizzle.IssueSubmissionException;
import org.codehaus.plexus.swizzle.IssueSubmissionRequest;
import org.sonatype.inject.Nullable;
import org.sonatype.sisu.pr.bundle.Bundle;
import org.sonatype.sisu.pr.bundle.BundleAssembler;
import org.sonatype.sisu.pr.bundle.FileBundle;

/**
 *
 */
@Named
@Singleton
public class LogBundleAssembler
    implements BundleAssembler
{

    private final File logfile;

    /**
     * @param logfile The file to use as a bundle. May be <code>null</code> to disable participation of this assembler.
     */
    @Inject
    public LogBundleAssembler( @Nullable @Named( "${pr.logfile}" ) final File logfile )
    {
        if ( logfile != null && !logfile.getName().equals( "${pr.logfile}" ) )
        {
            this.logfile = logfile;
        }
        else
        {
            this.logfile = null;
        }
    }

    /**
     * Log is included if ${pr.logfile} is set and exists.
     */
    @Override
    public boolean isParticipating( final IssueSubmissionRequest request )
    {
        return logfile != null && logfile.exists();
    }

    @Override
    public Bundle assemble( final IssueSubmissionRequest request )
        throws IssueSubmissionException
    {
        return new FileBundle( logfile );
    }

}
