/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.bundle.internal;

import java.io.UnsupportedEncodingException;

import javax.inject.Named;

import org.codehaus.plexus.swizzle.IssueSubmissionException;
import org.codehaus.plexus.swizzle.IssueSubmissionRequest;
import org.codehaus.plexus.util.ExceptionUtils;
import org.sonatype.sisu.pr.bundle.Bundle;
import org.sonatype.sisu.pr.bundle.BundleAssembler;

/**
 * Adds a text file containing the exception stacktrace.
 */
@Named
public class StackTraceAssembler
    implements BundleAssembler
{

    @Override
    public boolean isParticipating( final IssueSubmissionRequest request )
    {
        return request.getError() != null;
    }

    @Override
    public Bundle assemble( final IssueSubmissionRequest request )
        throws IssueSubmissionException
    {
        Bundle bundle;
        try
        {
            bundle = new ByteArrayBundle( ExceptionUtils.getFullStackTrace( request.getError() ).getBytes( "utf-8" ),
                    "exception.txt", "text/plain" );
        }
        catch ( UnsupportedEncodingException e )
        {
            throw new IssueSubmissionException( "Unsupported Encoding: UTF-8", e );
        }
        return bundle;
    }

}
