/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.filler.internal;

import javax.inject.Inject;
import javax.inject.Named;

import org.codehaus.plexus.swizzle.IssueSubmissionRequest;
import org.sonatype.inject.Nullable;
import org.sonatype.sisu.pr.Modifier;

@Named
public class PreconfiguredIssueTypeFillin
    implements Modifier
{

    private final String id;

    @Inject
    public PreconfiguredIssueTypeFillin( final @Nullable @Named( "${pr.issuetype.default}" ) String issueType )
    {
        this.id = issueType;
    }

    @Override
    public IssueSubmissionRequest modify( final IssueSubmissionRequest request )
    {
        if ( request.getIssueTypeId() == null )
        {
            if ( id != null && !"${pr.issuetype.default}".equals( id )  )
            {
                request.setIssueTypeId( id );
            }
            else
            {
                // JIRA 4.2 -> Bug
                request.setIssueTypeId( "1" );
            }
        }

        return request;
    }

    @Override
    public int getPriority()
    {
        return -1;
    }

}
