/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.filler.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.codehaus.plexus.swizzle.IssueSubmissionRequest;
import org.codehaus.plexus.util.ExceptionUtils;
import org.sonatype.sisu.pr.Modifier;

/**
 * Fill in summary and description based on the error set in the IssueSubmissionRequest.
 */
@Named
@Singleton
public class ThrowableIssueFillin
    implements Modifier
{

    @Override
    public IssueSubmissionRequest modify( final IssueSubmissionRequest request )
    {
        if ( request.getSummary() == null && request.getDescription() == null && request.getError() != null )
        {
            request.setSummary( request.getError().getMessage() );
            request.setDescription( ExceptionUtils.getFullStackTrace( request.getError() ) );
        }
        return request;
    }

    /**
     * Filling summary/description should come first.
     */
    @Override
    public int getPriority()
    {
        return Integer.MAX_VALUE;
    }

}
