/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.internal;

import javax.inject.Named;
import javax.inject.Singleton;


/**
 * @since 1.4
 */
@Named( "pr.default" )
@Singleton
public class DefaultSystemEnvironment
    implements SystemEnvironment
{

    @Override
    public String getJavaVendor()
    {
        return System.getProperty( "java.vendor" );
    }

    @Override
    public String getJavaVersion()
    {
        return System.getProperty( "java.version" );
    }

    @Override
    public String getOsName()
    {
        return System.getProperty( "os.name" );
    }

    @Override
    public String getOsVersion()
    {
        return System.getProperty( "os.version" );
    }

    @Override
    public String getOsArch()
    {
        return System.getProperty( "os.arch" );
    }

    @Override
    public int getAvailableProcessors()
    {
        return Runtime.getRuntime().availableProcessors();
    }

    @Override
    public long getMaxMemory()
    {
        return Runtime.getRuntime().maxMemory();
    }

    @Override
    public long getTotalMemory()
    {
        return Runtime.getRuntime().totalMemory();
    }

    @Override
    public long getFreeMemory()
    {
        return Runtime.getRuntime().freeMemory();
    }

}