/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.modifier.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.codehaus.plexus.swizzle.IssueSubmissionRequest;
import org.sonatype.sisu.pr.Modifier;

/**
 * JIRA truncates summary to 255 characters, so proactively truncate summary and add full summary to description.
 */
@Named
@Singleton
public class SummaryTruncationModifier
    implements Modifier
{

    @Override
    public IssueSubmissionRequest modify( final IssueSubmissionRequest request )
    {
        if ( request.getSummary() != null && request.getSummary().length() > 254 )
        {
            String summary = request.getSummary();
            request.setSummary( summary.substring( 0, 255 ) );
            request.setDescription( String.format( "Long Summary:\n%s\n\n%s", summary, request.getDescription() ) );
        }
        return request;
    }

    /**
     * Summary truncation should be last modifier.
     */
    @Override
    public int getPriority()
    {
        return Priority.MODIFIER.priority() - 5;
    }

}
