/**
 *  Copyright (c) 2008-2011 Sonatype, Inc. All rights reserved.
 *
 *  This program is licensed to you under the Apache License Version 2.0,
 *  and you may not use this file except in compliance with the Apache License Version 2.0.
 *  You may obtain a copy of the Apache License Version 2.0 at http://www.apache.org/licenses/LICENSE-2.0.
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the Apache License Version 2.0 is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 */
package org.sonatype.sisu.pr.modifier.internal;

import javax.inject.Inject;
import javax.inject.Named;

import org.codehaus.plexus.swizzle.IssueSubmissionRequest;
import org.codehaus.swizzle.jira.Component;
import org.codehaus.swizzle.jira.Project;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.sonatype.sisu.issue.IssueRetrievalException;
import org.sonatype.sisu.issue.IssueRetriever;
import org.sonatype.sisu.pr.Modifier;

@Named
public class TranslateComponentIdModifier
    implements Modifier
{

    private static final Logger logger = LoggerFactory.getLogger( TranslateComponentIdModifier.class );

    private final IssueRetriever retriever;

    @Inject
    public TranslateComponentIdModifier( final IssueRetriever retriever )
    {
        this.retriever = retriever;
    }

    @Override
    public IssueSubmissionRequest modify( final IssueSubmissionRequest request )
    {
        String component = request.getComponent();
        try
        {
            Integer.valueOf( component );
        }
        catch ( NumberFormatException e )
        {
            try
            {
                String projectKey = request.getProjectKey();
                if ( projectKey != null )
                {
                    Project project = retriever.getProject( projectKey );
                    Component sComponent = retriever.getComponent( project, component );
                    request.setComponent( String.valueOf( sComponent.getId() ) );
                }
            }
            catch ( Exception ignore )
            {
                // ignore, cannot do anything
                logger.warn( "Could not translate component name to id: " + component + "(" + request.getProjectKey()
                    + ")" );
            }
        }

        return request;
    }

    @Override
    public int getPriority()
    {
        return Priority.MODIFIER.priority();
    }

}
